SUBROUTINE GPHLWI(KPROMA,KSTART,KPROF,PLNPR,PALPH,PWW,CDLOCK)

!**** *GPHLWI* - to half-levels interpolation weights

!     Purpose.
!     --------
!           Compute weights for interpolation of winds to
!           half levels (in non-hydrostatic dynamics)

!**   Interface.
!     ----------
!        *CALL* *GPHLWI(

!        Explicit arguments :
!        --------------------

!        Implicit arguments : none.
!        --------------------

!     Method.
!     -------
!        Interpolation from full-levels using logaritmic pressure profile
!        Then modify values on the top and bottom using boundary condition
!        (at the bottom free-slip condition)
!        Store the weights of vertical interpolation

!     Externals.
!     ----------
!     Reference.
!     ----------
!        ARPEGE/ALADIN documentation

!     Author.
!     -------
!        Radmila Bubnova,  CNRM/GMAP/EXT

!     Modifications.
!     --------------
!        Original : November 1997
!        Modified 02-07-02 by C. Fischer : remove pww5 computation + intents
!        01-Oct-2003 M. Hamrud   CY28 Cleaning.
!        02-Jan-2006 J. Masek    Adapted for use with flux, cpp macro PALADIN
!                                introdced for better portability.
!     ----------------------------------------------------------------------

USE MOD_AUX, ONLY: NFLEVG

!*       0.    ARGUMENTS.
!              ----------

IMPLICIT NONE

INTEGER,INTENT(IN)    :: KPROMA 
INTEGER,INTENT(IN)    :: KSTART 
INTEGER,INTENT(IN)    :: KPROF 
REAL   ,INTENT(IN)    :: PLNPR(KPROMA,NFLEVG) 
REAL   ,INTENT(IN)    :: PALPH(KPROMA,NFLEVG) 
REAL   ,INTENT(OUT)   :: PWW(KPROMA,NFLEVG) 
CHARACTER(LEN=6)  ,INTENT(IN)    :: CDLOCK 
INTEGER :: JLEV, JROF

!     ------------------------------------------------------------------

!     CHECK RELIABILITY OF INPUT ARGUMENTS.

#ifdef PALADIN
IF(CDLOCK /= 'GPHLWI') CALL ABOR2('GPHLWI: BAD NUMBER OF ARGUMENTS!')
#else
IF(CDLOCK /= 'GPHLWI') CALL ABOR1('GPHLWI: BAD NUMBER OF ARGUMENTS!')
#endif

DO JROF=KSTART,KPROF
  DO JLEV=1, NFLEVG - 1

    PWW(JROF,JLEV)=(PLNPR(JROF,JLEV+1)-PALPH(JROF,JLEV+1))&
     & /(PLNPR(JROF,JLEV+1)-PALPH(JROF,JLEV+1)+PALPH(JROF,JLEV))  

  ENDDO
ENDDO

!     ------------------------------------------------------------------

DO JROF=KSTART,KPROF

!* Bottom half level: 

  PWW(JROF,NFLEVG) = 0.0

ENDDO

END SUBROUTINE GPHLWI
