SUBROUTINE GPPREH(KPROMA,KSTART,KPROF,KFLEV,PVAH,PVBH,PRESH)

!**** *GPPREH* - Computes half and full level pressure

!     Purpose.
!     --------
!           Computes pressures at half and full model levels.

!**   Interface.
!     ----------
!        *CALL* *GPPREH(KPROMA,KSTART,KPROF,KFLEV,PVAH,PVBH,PRESH)

!        Explicit arguments :
!        --------------------
!                              KPROMA :  dimensioning
!                              KSTART :  start of work
!                              KPROF  :  depth of work
!                              KFLEV     : vert. dimensioning
!                              PRESH(KPROMA,0:KFLEV) - HALF LEVEL PRESSURE
!                              PVAH(KFLEV),PVBH(KFLEV)- vertical coordinate
!        Implicit arguments :  NONE.
!        --------------------

!     Method.
!     -------
!        See documentation

!     Externals.  None.
!     ----------

!     Reference.
!     ----------
!        ECMWF Research Department documentation of the IFS
!     Half level P:     PHk = Ak + Bk * Ps

!     Author.
!     -------
!        Erik Andersson, Mats Hamrud and Philippe Courtier  *ECMWF*

!     Modifications.
!     --------------
!        Original : 92-11-23
!        01-Oct-2003 M. Hamrud   CY28 Cleaning.
!        02-Jan-2006 J. Masek    Adapted for use with flux.
!     ------------------------------------------------------------------

IMPLICIT NONE

INTEGER,INTENT(IN)    :: KPROMA 
INTEGER,INTENT(IN)    :: KFLEV 
INTEGER,INTENT(IN)    :: KSTART 
INTEGER,INTENT(IN)    :: KPROF 
REAL   ,INTENT(IN)    :: PVAH(0:KFLEV) 
REAL   ,INTENT(IN)    :: PVBH(0:KFLEV) 
REAL   ,INTENT(INOUT) :: PRESH(KPROMA,0:KFLEV) 
INTEGER :: JLEV, JLON

!     ------------------------------------------------------------------

!*       1.    COMPUTES HALF LEVEL PRESSURES.
!              ------------------------------

DO JLEV=0,KFLEV-1
  DO JLON=KSTART,KPROF
    PRESH(JLON,JLEV)=PVAH(JLEV)+PVBH(JLEV)*PRESH(JLON,KFLEV)
  ENDDO
ENDDO

!     ------------------------------------------------------------------

END SUBROUTINE GPPREH
