subroutine spec2real(&
  & ptrigs ,&! (I) - tabulated sin and cos for FFT
  & kfax   ,&! (I) - prime factors list of the Fourier vectors length
  & pspec  ,&! (I) - spectral field
  & preal   &! (O) - gridpoint field
&)

! -----
! PURPOSE:
!   spectral ---> gridpoint transforms for 2D vertical plane 
!   model diagnostics
!
! METHOD:
!   Input array pspec contains spectral coefficients
!   ordered as in 2D vertical plane ALADIN file.
!   Output array preal contains gridpoint values.
!
! EXTERNALS:
!   fft991 or fft992  (xrd)
!         
! REFERENCE:
!   Meteo-France CNRM/GMAP
!
! ORIGINAL:
!   ??-10-1998, Pierre Benard
!
! MODIFICATIONS:
!   16-08-2002, J. Masek:
!     Thinned interface, cleaning, rewriting into free from.
!
!   02-01-2006, J. Masek:   
!     All modules merged into mod_aux, cpp macro PALADIN introdced for better 
!     portability.
!
! -----

use mod_aux, only: ndgl, nsefre, nsmax

implicit none

! -----
! I/O arguments
! -----

integer, intent(in) :: kfax(20)

real, intent(in)  :: ptrigs(ndgl), pspec(nsefre)
real, intent(out) :: preal (ndgl)

! -----
! local variables
! -----
      
integer :: ifft, jn
integer :: ilot, inc, isign

! -----
! local arrays
! -----

real :: zreal(ndgl + 2), zwork(ndgl + 1)

! =====

! -----
! reorder spectral coefficients: 2D vertical plane ALADIN file ---> FFT
! -----

! initialize I/O array with zeroes
zreal(:) = 0.0

! fill in spectral coefficients relevant for 2D model
ifft = 1
do jn = 0, nsmax
  zreal(ifft) = pspec(4*jn + 1)
  ifft        = ifft + 1
  zreal(ifft) = pspec(4*jn + 2)
  ifft        = ifft + 1
enddo

! -----
! spec ---> real transformation
! -----
      
! preparations
inc   = 1  ! increment within data vector
ilot  = 1  ! number of data vectors
isign = 1  ! spectral ---> gridpoint transformation

! Fourier transform (zreal is used for I/O, zwork is unused)
#ifdef PALADIN
call fft991(zreal, zwork, ptrigs, kfax, inc, ndgl, ndgl, ilot, isign)
#else
call fft992(zreal, ptrigs, kfax, inc, ndgl, ndgl, ilot, isign)
#endif

! copy results to output array
preal(1:ndgl) = zreal(1:ndgl)

return
end subroutine spec2real

