subroutine setup_modules(&
  & kulout  ,&! (I) - logical unit for output messages
  & kdgl    ,&! (I) - number of latitude rows
  & kflevg  ,&! (I) - number of full levels
  & ksefre  ,&! (I) - number of degrees of freedom in spectral space
  & knsmax  ,&! (I) - truncation in latitude
  & ply     ,&! (I) - length of domain in y direction
  & pdely   ,&! (I) - grid size in y direction
  & ldnhdyn  &! (I) - switch for NH dynamics
&)

! -----
! PURPOSE:
!   Initialization of necessary module variables needed for external
!   ARPEGE/ALADIN subroutines.
!
! EXTERNALS:
!   sucst  (arp)
!
! ORIGINAL:
!   16-08-2002, J. Masek
!
! MODIFICATIONS:
!
! -----

use yemgeo , only: ely, edely

use yomct0 , only: laprxpk, lnhdyn, lrubc, lvercor, lvslwbc
use yomcver, only: lvertfe
use yomdim , only: lgpl, lgpi, lspl, lspi, ndgl => ndglg,  &
  &                nflevg, nsefre, nsmax
use yomdyn , only: ndlnpr, rhydr0
use yomlun , only: nulout

implicit none

! -----
! I/O arguments
! -----

integer, intent(in) :: kulout, kdgl, kflevg, ksefre, knsmax

real, intent(in) :: ply, pdely

logical, intent(in) :: ldnhdyn

! -----
! local variables
! -----

integer :: idate, ipl, isec

! =====

! -----
! yemgeo
! -----

ely   = ply    ! length of domain in y direction
edely = pdely  ! grid size in y direction

! -----
! yomcst
! -----

idate = 20000101  ! date in format yyyymmdd
isec  = 86400     ! number of seconds
ipl   = 0         ! printlevel

call sucst(kulout, idate, isec, ipl)

! -----
! yomct0
! -----

laprxpk = .FALSE.  ! use exact formula for full level pressure
lrubc   = .FALSE.  ! deactivate RUBC
lvercor = .FALSE.  ! apply thin layer hypothesis
lvslwbc = .FALSE.  ! surface wind assumed the same as on lowest full level

! -----
! yomcver
! -----

lvertfe = .FALSE.  ! do not use finite elements in vertical

! -----
! yomdim
! -----

! no prognostic liquid water
lgpl = .FALSE.
lspl = .FALSE.

! no prognostic ice
lgpi = .FALSE.
lspi = .FALSE.

! dimensions
ndgl   = kdgl    ! number of latitude rows
nflevg = kflevg  ! number of full levels
nsefre = ksefre  ! number of degrees of freedom in spectral space
nsmax  = knsmax  ! truncation in latitude

! -----
! yomdyn
! -----

! switch for NH dynamics
lnhdyn = ldnhdyn

if ( ldnhdyn ) then
  ndlnpr = 1  ! use NH formula for d(pi)/pi
else
  ndlnpr = 0  ! use hydrostatic formula for d(pi)/pi
endif
rhydr0 = 1.0  ! upper boundary contition for hydrostatic

! -----
! yomlun
! -----

nulout = kulout  ! logical unit number for output messages

! -----

return
end subroutine setup_modules

