subroutine vvel(&
  & pvbh   ,&! (I) - vertical function B on half levels
  & pvdelb ,&! (I) - delta(B) across the layers
  & pim_s  ,&! (I) - derivative of surface pressure pi_S
  & pv     ,&! (I) - v wind
  & pvm    ,&! (I) - derivative of v wind (horizontal divergence)
  & pdelp  ,&! (I) - delta(pi) across the layers
  & prdelp ,&! (I) - 1/delta(pi)
  & plnpr  ,&! (I) - delta term (approximation of d(pi)/pi)
  & palph  ,&! (I) - alpha term
  & prtgr  ,&! (I) - conversion term
  & prpref ,&! (I) - 1/pi on full levels
  & pvvel   &! (O) - omega/pi
&)

! -----
! PURPOSE:
!   Diagnostics of term omega/pi (omega = d/dt pi) for 2D vertical 
!   plane ALADIN. Calls gpcty.
!
! EXTERNALS:
!   gpcty  (arp)
!
! ORIGINAL:
!   16-08-2002, J. Masek
!
! MODIFICATIONS:
!
! -----

use yomct0, only: lrubc, lvercor
use yomdim, only: ndgl => ndglg, nflevg

implicit none

! -----
! I/O arguments
! -----

real, intent(in)  :: pvbh  (0:nflevg)
real, intent(in)  :: pvdelb(  nflevg)

real, intent(in)  :: pim_s(ndgl)

real, intent(in)  :: pv    (ndgl,   nflevg)
real, intent(in)  :: pvm   (ndgl,   nflevg)
real, intent(in)  :: pdelp (ndgl,   nflevg)
real, intent(in)  :: prdelp(ndgl,   nflevg)
real, intent(in)  :: plnpr (ndgl,   nflevg)
real, intent(in)  :: palph (ndgl,   nflevg)
real, intent(in)  :: prtgr (ndgl,   nflevg)
real, intent(in)  :: prpref(ndgl,   nflevg)

real, intent(out) :: pvvel (ndgl,   nflevg)

! -----
! local arrays
! -----

real :: zevt  (ndgl)
real :: zpil_s(ndgl)

real :: zu       (ndgl,   nflevg)
real :: zvcrssaf (ndgl,   nflevg)
real :: zvcrssah (ndgl, 0:nflevg)
real :: zvcasrsf (ndgl,   nflevg)
real :: zvcasrsh (ndgl, 0:nflevg)
real :: zvcrssafl(ndgl,   nflevg)
real :: zvcrssafm(ndgl,   nflevg)
real :: zevel    (ndgl, 0:nflevg)
real :: zsdiv    (ndgl, 0:nflevg)
real :: zsdvbc   (ndgl, 0:nflevg)
real :: zdivdp   (ndgl,   nflevg)

! =====

zevt  (:) = 0.0
zpil_s(:) = 0.0

zu       (:, :) = 0.0
zvcrssaf (:, :) = 0.0
zvcrssah (:, :) = 0.0
zvcasrsf (:, :) = 0.0
zvcasrsh (:, :) = 0.0
zvcrssafl(:, :) = 0.0
zvcrssafm(:, :) = 0.0

! compute omega/pi (array pvvel)
call gpcty(lvercor, ndgl, ndgl, 1, ndgl, nflevg, pvdelb, pvbh,  &
  &  zu, pv, pvm, zevt, lrubc,  &
  &  pdelp, prdelp, plnpr, palph, prtgr, zpil_s, pim_s,  &
  &  zvcrssaf, zvcrssah, zvcasrsf, zvcasrsh, zvcrssafl, zvcrssafm,  &
  &  zevel, pvvel, zsdiv, zsdvbc, zdivdp, prpref, 'GPCTY')

return
end subroutine vvel

