subroutine real2spec( &
  & ptrigs ,&! (I) - tabulated sin and cos for FFT
  & kfax   ,&! (I) - prime factors list of the Fourier vectors length
  & preal  ,&! (I) - gridpoint field
  & pspec   &! (O) - spectral field
&)

! -----
! PURPOSE:
!   gridpoint ---> spectral transforms for 2D vertical plane 
!   model diagnostics
!
! METHOD:
!   Input array preal contains gridpoint values.
!   Output array pspec contains spectral coefficients
!   ordered as in 2D vertical plane ALADIN file.
!
! EXTERNALS:
!   fft992  (xrd)
!         
! REFERENCE:
!   Meteo-France CNRM/GMAP
!
! ORIGINAL:
!   ??-10-1998, Pierre Benard
!
! MODIFICATIONS:
!   16-08-2002, J. Masek:
!     Thinned interface, cleaning, rewriting into free from.
!
! -----

use yomdim, only: ndgl => ndglg, nsefre, nsmax

implicit none

! -----
! I/O arguments
! -----

integer, intent(in) :: kfax(20)

real, intent(in)  :: ptrigs(ndgl), preal(ndgl)
real, intent(out) :: pspec(nsefre)

! -----
! local variables
! -----
      
integer :: ifft, jn
integer :: ilot, inc, isign

! -----
! local arrays
! -----

real :: zreal(ndgl + 2)

! =====

! -----
! spec ---> real transformation
! -----

! initialize I/O array
zreal(1:ndgl)   = preal(1:ndgl)
zreal(ndgl + 1) = 0.0
zreal(ndgl + 2) = 0.0

! preparations
inc   =  1  ! increment within data vector
ilot  =  1  ! number of data vectors
isign = -1  ! gridpoint ---> spectral transformation

! Fourier transform (zreal is used for I/O)
call fft992(zreal, ptrigs, kfax, inc, ndgl, ndgl, ilot, isign)

! -----
! reorder spectral coefficients: FFT ---> 2D vertical plane ALADIN file
! -----

! initialize output array with zeroes
pspec(:) = 0.0

! reorder coefficients
ifft = 1
do jn = 0, nsmax
  pspec(4*jn + 1) = zreal(ifft)
  ifft            = ifft + 1
  pspec(4*jn + 2) = zreal(ifft)
  ifft            = ifft + 1
enddo

return
end subroutine real2spec

