subroutine specder(&
  & pspec  ,&! (I) - spectral coefficients of original field
  & pspecm  &! (O) - spectral coefficients of its horizontal derivative
&)

! -----
! PURPOSE:
!   Spectral computation of horizontal derivative for 2D vertical 
!   plane model.
!
! METHOD:
!   Input array pspec contains spectral coefficients of original field.
!   Output array pspecm contains spectral coefficients of its horizontal
!   derivative.
!   Spectral coefficients are ordered as in 2D vertical plane ALADIN
!   file.
!
! ORIGINAL:
!   ??
!
! MODIFICATIONS:
!   16-08-2002, J. Masek:
!     Thinned interface, cleaning, rewriting into free from.
!
! -----

use yemgeo, only: ely

use yomcst, only: rpi
use yomdim, only: nsefre, nsmax

implicit none

! -----
! I/O arguments
! -----

real, intent(in)  :: pspec (nsefre)
real, intent(out) :: pspecm(nsefre)

! -----
! local variables
! -----

integer :: i1, i2, jn

real :: zcoef

! =====

! initialize derivative
pspecm(:) = 0.0

! compute derivative in y direction
do jn = 0, nsmax
  i1         = 4*jn + 1
  i2         = 4*jn + 2
  zcoef      = (2.*rpi/ely)*jn
  pspecm(i1) = -zcoef*pspec(i2)
  pspecm(i2) = +zcoef*pspec(i1)
enddo

return
end subroutine specder

